#!/bin/sh

GS_PACKAGE_LOG="/var/log/goodsync-install.log"
echo "post-install.sh called" >> "$GS_PACKAGE_LOG"

GS_PROFILE="$APKG_PKG_DIR/etc"

echo "post_install.sh: GS_PROFILE=$GS_PROFILE" >> "$GS_PACKAGE_LOG"

# sanity checks
if [ -z "$APKG_PKG_DIR" ]; then
  echo "post_install.sh: empty APKG_PKG_DIR!" >> "$GS_PACKAGE_LOG"
  exit 1
fi

mkdir "$GS_PROFILE" ||\
  { echo "post_install.sh: failed to create profile folder!" >> "$GS_PACKAGE_LOG"; exit 2; }

# Generate RSA key using platform openssl, for Web UI setup to use
openssl genrsa -out "$APKG_PKG_DIR/res/gs-connect-key.in" 2048

GS_OS_SERVER_PROFILE="$GS_PROFILE" "$APKG_PKG_DIR/bin/gs-server" /profile="$GS_PROFILE" /make-nas-install-settings=asustor >> "$GS_PACKAGE_LOG"

chown -R admin:administrators "$GS_PROFILE" ||\
  { echo "post_install.sh: failed to chown profile folder!" >> "$GS_PACKAGE_LOG"; exit 3; }
chmod -R 766 "$GS_PROFILE" ||\
  { echo "post_install.sh: failed to chmod profile folder!" >> "$GS_PACKAGE_LOG"; exit 4; }

# Set up SMB paths
sed -i 's|SMBConfPath =.*|SMBConfPath = \"/volume0/usr/builtin/etc/samba/smb.conf\"|' "$GS_PROFILE/settings.tix" ||\
  { echo "post_install.sh: failed to sed SMBConfPath!" >> "$GS_PACKAGE_LOG"; exit 5; }

sed -i 's|SMBSharePrefix =.*|SMBSharePrefix = \"/share\"|' "$GS_PROFILE/settings.tix" ||\
  { echo "post_install.sh: failed to sed SMBSharePrefix!" >> "$GS_PACKAGE_LOG"; exit 6; }

exit 0
