#!/bin/sh

PROFILE="$APKG_PKG_DIR/etc"
DAEMON_USER="admin"
DAEMON_ARGS="/profile=$PROFILE /resources=$APKG_PKG_DIR/res /webui-nas"
DAEMON="$APKG_PKG_DIR/bin/gs-server"
PID="$PROFILE/gs-server.pid"

start_daemon() {
        start-stop-daemon --background -S --quiet --user "${DAEMON_USER}" --pidfile "${PID}" --make-pidfile --chuid="$DAEMON_USER":administrators --exec /usr/bin/env GS_OS_SERVER_PROFILE="$PROFILE" "$DAEMON" $DAEMON_ARGS
}

stop_daemon() {
        start-stop-daemon -K --quiet --user "${DAEMON_USER}" --pidfile "${PID}"
}

daemon_status() {
        start-stop-daemon -K --quiet --test --user "${DAEMON_USER}" --pidfile "${PID}"
	RETVAL=$?
	[ ${RETVAL} -eq 0 ] || return 1
}

wait_for_status() {
	counter=$2
	while [ "$counter" -gt 0 ]; do
		daemon_status
		[ $? -eq "$1" ] && return
		counter=$(( counter - 1 ))
		sleep 1
	done
	return 1
}

case $1 in
	start)
		if daemon_status; then
			echo "${NAME} is already running"
		else
			echo "Starting ${NAME}..."
			start_daemon
		fi
		;;

	stop)
		if daemon_status; then
			echo "Stopping ${NAME}..."
			stop_daemon
		else
			echo "${NAME} is not running"
		fi
		;;
	restart)
		if daemon_status; then
			echo "Stopping ${NAME}..."
			stop_daemon
		fi
		echo "Starting ${NAME}..."
		start_daemon
		;;
	status)
		if daemon_status; then
			echo "${NAME} is running"
			exit 0
		else
			echo "${NAME} is not running"
			exit 1
		fi
		;;
	*)
		echo "usage: $0 {start|stop|restart|status}"
		exit 1
		;;
esac

exit 0
